/// <reference types="react" />
import { StyleProp, TextStyle, ViewStyle, LayoutChangeEvent } from 'react-native';
import Animated from 'react-native-reanimated';
import { EdgeInsets } from 'react-native-safe-area-context';
import { NavigationRoute, NavigationState, NavigationScreenProp, NavigationParams, NavigationNavigateAction, NavigationAction, NavigationEventCallback, NavigationEventSubscription, NavigationDescriptor, NavigationScreenConfig, SupportedThemes } from 'react-navigation';
export declare type NavigationStackEventName = 'willFocus' | 'didFocus' | 'willBlur' | 'didBlur';
export declare type NavigationStackState = NavigationState;
export declare type NavigationStackProp<State = NavigationRoute, Params = NavigationParams> = NavigationScreenProp<State, Params> & {
    push: (routeName: string, params?: NavigationParams, action?: NavigationNavigateAction) => boolean;
    replace: (routeName: string, params?: NavigationParams, action?: NavigationNavigateAction) => boolean;
    reset: (actions: NavigationAction[], index: number) => boolean;
    pop: (n?: number, params?: {
        immediate?: boolean;
    }) => boolean;
    popToTop: (params?: {
        immediate?: boolean;
    }) => boolean;
    addListener: (event: NavigationStackEventName, callback: NavigationEventCallback) => NavigationEventSubscription;
};
export declare type Layout = {
    width: number;
    height: number;
};
export declare type GestureDirection = 'horizontal' | 'vertical' | 'vertical-inverted';
export declare type HeaderMode = 'float' | 'screen' | 'none';
export declare type HeaderScene<T = NavigationRoute> = {
    route: T;
    descriptor: NavigationDescriptor<NavigationParams, NavigationStackOptions>;
    progress: {
        current: Animated.Node<number>;
        next?: Animated.Node<number>;
        previous?: Animated.Node<number>;
    };
};
export declare type HeaderOptions = {
    headerTitle?: React.ReactNode | ((props: HeaderTitleProps) => React.ReactNode);
    headerTitleAlign?: 'left' | 'center';
    headerTitleStyle?: StyleProp<TextStyle>;
    headerTitleContainerStyle?: StyleProp<ViewStyle>;
    headerTintColor?: string;
    headerLeftTintColor?: string;
    headerRightTintColor?: string;
    headerTitleAllowFontScaling?: boolean;
    headerBackAllowFontScaling?: boolean;
    headerBackTitle?: string;
    headerBackTitleStyle?: StyleProp<TextStyle>;
    headerBackTitleVisible?: boolean;
    headerTruncatedBackTitle?: string;
    headerLeft?: React.ReactNode | ((props: HeaderBackButtonProps) => React.ReactNode);
    headerLeftContainerStyle?: StyleProp<ViewStyle>;
    headerRight?: React.ReactNode | ((props: {
        tintColor?: string;
    }) => React.ReactNode);
    headerRightContainerStyle?: StyleProp<ViewStyle>;
    headerBackImage?: HeaderBackButtonProps['backImage'];
    headerPressColorAndroid?: string;
    headerBackground?: React.ReactNode | (() => React.ReactNode);
    headerStyle?: StyleProp<ViewStyle>;
    headerTransparent?: boolean;
};
export declare type HeaderProps = {
    mode: 'float' | 'screen';
    layout: Layout;
    insets: EdgeInsets;
    scene: HeaderScene;
    previous?: HeaderScene;
    navigation: NavigationStackProp;
    styleInterpolator: HeaderStyleInterpolator;
};
export declare type TransitionCallbackProps = {
    closing: boolean;
};
export declare type NavigationStackOptions = HeaderOptions & Partial<TransitionPreset> & {
    title?: string;
    header?: React.ReactNode | ((props: HeaderProps) => React.ReactNode);
    headerShown?: boolean;
    cardShadowEnabled?: boolean;
    cardOverlayEnabled?: boolean;
    cardTransparent?: boolean;
    cardStyle?: StyleProp<ViewStyle>;
    animationEnabled?: boolean;
    gestureEnabled?: boolean;
    gestureResponseDistance?: {
        vertical?: number;
        horizontal?: number;
    };
    onTransitionStart?: (props: TransitionCallbackProps) => void;
    onTransitionEnd?: (props: TransitionCallbackProps) => void;
    gestureVelocityImpact?: number;
    safeAreaInsets?: {
        top?: number;
        right?: number;
        bottom?: number;
        left?: number;
    };
};
export declare type NavigationStackConfig = {
    mode?: 'card' | 'modal';
    headerMode?: HeaderMode;
    disableKeyboardHandling?: boolean;
};
export declare type NavigationStackScreenProps<Params = NavigationParams, ScreenProps = unknown> = {
    theme: SupportedThemes;
    navigation: NavigationStackProp<NavigationRoute, Params>;
    screenProps: ScreenProps;
};
export declare type NavigationStackScreenComponent<Params = NavigationParams, ScreenProps = unknown> = React.ComponentType<NavigationStackScreenProps<Params, ScreenProps>> & {
    navigationOptions?: NavigationScreenConfig<NavigationStackOptions, NavigationStackProp<NavigationRoute, Params>, ScreenProps>;
};
export declare type SceneDescriptorMap = {
    [key: string]: NavigationDescriptor<NavigationParams, NavigationStackOptions, NavigationStackProp> | undefined;
};
export declare type HeaderBackButtonProps = {
    disabled?: boolean;
    onPress?: () => void;
    pressColorAndroid?: string;
    backImage?: React.ReactNode | ((props: {
        tintColor: string;
    }) => React.ReactNode);
    tintColor?: string;
    label?: string;
    truncatedLabel?: string;
    labelVisible?: boolean;
    labelStyle?: React.ComponentProps<typeof Animated.Text>['style'];
    allowFontScaling?: boolean;
    onLabelLayout?: (e: LayoutChangeEvent) => void;
    screenLayout?: Layout;
    titleLayout?: Layout;
    canGoBack?: boolean;
};
export declare type HeaderTitleProps = {
    onLayout: (e: LayoutChangeEvent) => void;
    allowFontScaling?: boolean;
    children?: React.ReactNode;
    style?: StyleProp<TextStyle>;
};
export declare type SpringConfig = {
    damping: number;
    mass: number;
    stiffness: number;
    restSpeedThreshold: number;
    restDisplacementThreshold: number;
    overshootClamping: boolean;
};
export declare type TimingConfig = {
    duration: number;
    easing: Animated.EasingFunction;
};
export declare type TransitionSpec = {
    animation: 'spring';
    config: SpringConfig;
} | {
    animation: 'timing';
    config: TimingConfig;
};
export declare type CardInterpolationProps = {
    current: {
        progress: Animated.Node<number>;
    };
    next?: {
        progress: Animated.Node<number>;
    };
    index: number;
    closing: Animated.Node<0 | 1>;
    layouts: {
        screen: Layout;
    };
    insets: EdgeInsets;
};
export declare type CardInterpolatedStyle = {
    containerStyle?: any;
    cardStyle?: any;
    overlayStyle?: any;
    shadowStyle?: any;
};
export declare type CardStyleInterpolator = (props: CardInterpolationProps) => CardInterpolatedStyle;
export declare type HeaderInterpolationProps = {
    current: {
        progress: Animated.Node<number>;
    };
    next?: {
        progress: Animated.Node<number>;
    };
    layouts: {
        screen: Layout;
        title?: Layout;
        leftLabel?: Layout;
    };
};
export declare type HeaderInterpolatedStyle = {
    leftLabelStyle?: any;
    leftButtonStyle?: any;
    rightButtonStyle?: any;
    titleStyle?: any;
    backgroundStyle?: any;
};
export declare type HeaderStyleInterpolator = (props: HeaderInterpolationProps) => HeaderInterpolatedStyle;
export declare type TransitionPreset = {
    gestureDirection: GestureDirection;
    transitionSpec: {
        open: TransitionSpec;
        close: TransitionSpec;
    };
    cardStyleInterpolator: CardStyleInterpolator;
    headerStyleInterpolator: HeaderStyleInterpolator;
};
